==> haskell-store-0.5.1.2-25-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-store.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: store
version: 0.5.1.2
id: store-0.5.1.2-DPeeAiDaKo4awYyaoOild
key: store-0.5.1.2-DPeeAiDaKo4awYyaoOild
license: MIT
copyright: 2016 FP Complete
maintainer: Michael Sloan <sloan@fpcomplete.com>
homepage: https://github.com/fpco/store#readme
synopsis: Fast binary serialization
category: Serialization, Data
abi: d9aaa1f2163b0ce9fe27c81a39474914
exposed: True
exposed-modules:
    Data.Store Data.Store.Internal Data.Store.TH Data.Store.TH.Internal
    Data.Store.TypeHash Data.Store.TypeHash.Internal Data.Store.Version
    System.IO.ByteBuffer
hidden-modules: Data.Store.Impl
import-dirs: /usr/lib/ghc-8.6.5/site-local/store-0.5.1.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/store-0.5.1.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/store-0.5.1.2
hs-libraries: HSstore-0.5.1.2-DPeeAiDaKo4awYyaoOild
depends:
    array-0.5.3.0 async-2.2.2-5KbUJa8fnnu9oaTmXcEjsG base-4.12.0.0
    base-orphans-0.8.1-6XlhSm6oZf21np9NDzyPU3
    base64-bytestring-1.0.0.2-27dSAr8bLTq6kAjQ5MgzSz
    bifunctors-5.5.6-1hzbr6CRsZhGc3TV5tucLZ bytestring-0.10.8.2
    containers-0.6.0.1 contravariant-1.5.2-IGTyLqhZC2pCTY0qng5HHQ
    cryptohash-0.11.9-CoTMowpthlAFX290whuknU deepseq-1.4.4.0
    directory-1.3.3.0 filepath-1.4.2.1
    free-5.1.2-6EqrYTKjKSl2dnY4P2nHLx ghc-prim-0.5.3
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    hspec-2.7.1-HJCUFd7ibyAFZeyKsOubud
    hspec-smallcheck-0.5.2-7sgb8dlJ1K66stvzt5dFxj integer-gmp-1.0.2.0
    lifted-base-0.2.3.12-B4DztZYcWo5FX71P7R1jj6
    monad-control-1.0.2.3-8Pxhw440UA44O8KsVrptNh
    mono-traversable-1.0.13.0-BJsqQErYvVJ330wkWEJQ8I
    network-2.8.0.0-GWaLTJJGEavAfd7Abho21R
    primitive-0.6.4.0-ILgywxtLpvnAOlEISPpP5b
    resourcet-1.2.2-JLxEmnu4VEmKsSbOPjgbf0
    safe-0.3.17-43oyx4B630gDZMbTh3Ttji
    smallcheck-1.1.5-IcJgcWLNXQN4xE4F00EnpE
    store-core-0.4.4.1-88VHVSUIahwun1lQttQeS
    syb-0.7.1-1gO4OjQOULM8usUjWwwEyW template-haskell-2.14.0.0
    text-1.2.3.1 th-lift-0.8.0.1-27iw5a8l71Jv8yDjPHfmr
    th-lift-instances-0.1.14-KASYyJM441aGLVgajki6ev
    th-orphans-0.13.9-Kj7oG1a3gHoFLKxAz30Iyt
    th-reify-many-0.1.9-G89688xYWjfFURMqNvAi7B
    th-utilities-0.2.3.1-3qJ3GV8o7vFIOfKV3fH5x1 time-1.8.0.2
    transformers-0.5.6.2
    unordered-containers-0.2.10.0-AdFIXUUlSRM50nV4OuQt9A
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
    void-0.7.3-3RYOrpJEx0UYkI9Ikv0XI
haddock-interfaces: /usr/share/doc/haskell-store/html/store.haddock
haddock-html: /usr/share/doc/haskell-store/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-store-0.5.1.2-27-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-store.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: store
version: 0.5.1.2
id: store-0.5.1.2-JlbJozcUOmTDaCnBBJHJ68
key: store-0.5.1.2-JlbJozcUOmTDaCnBBJHJ68
license: MIT
copyright: 2016 FP Complete
maintainer: Michael Sloan <sloan@fpcomplete.com>
homepage: https://github.com/fpco/store#readme
synopsis: Fast binary serialization
category: Serialization, Data
abi: 7f1f2c0184ff0ca2df55d1e3533a45ee
exposed: True
exposed-modules:
    Data.Store Data.Store.Internal Data.Store.TH Data.Store.TH.Internal
    Data.Store.TypeHash Data.Store.TypeHash.Internal Data.Store.Version
    System.IO.ByteBuffer
hidden-modules: Data.Store.Impl
import-dirs: /usr/lib/ghc-8.6.5/site-local/store-0.5.1.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/store-0.5.1.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/store-0.5.1.2
hs-libraries: HSstore-0.5.1.2-JlbJozcUOmTDaCnBBJHJ68
depends:
    array-0.5.3.0 async-2.2.2-5KbUJa8fnnu9oaTmXcEjsG base-4.12.0.0
    base-orphans-0.8.1-6XlhSm6oZf21np9NDzyPU3
    base64-bytestring-1.0.0.2-27dSAr8bLTq6kAjQ5MgzSz
    bifunctors-5.5.6-1hzbr6CRsZhGc3TV5tucLZ bytestring-0.10.8.2
    containers-0.6.0.1 contravariant-1.5.2-IGTyLqhZC2pCTY0qng5HHQ
    cryptohash-0.11.9-CoTMowpthlAFX290whuknU deepseq-1.4.4.0
    directory-1.3.3.0 filepath-1.4.2.1
    free-5.1.3-16riWRkMrEyBwwRAzko3GF ghc-prim-0.5.3
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    hspec-2.7.1-HJCUFd7ibyAFZeyKsOubud
    hspec-smallcheck-0.5.2-7sgb8dlJ1K66stvzt5dFxj integer-gmp-1.0.2.0
    lifted-base-0.2.3.12-B4DztZYcWo5FX71P7R1jj6
    monad-control-1.0.2.3-8Pxhw440UA44O8KsVrptNh
    mono-traversable-1.0.13.0-QNdr8x00wgCJ6mFJNdrsO
    network-2.8.0.0-GWaLTJJGEavAfd7Abho21R
    primitive-0.6.4.0-ILgywxtLpvnAOlEISPpP5b
    resourcet-1.2.2-JLxEmnu4VEmKsSbOPjgbf0
    safe-0.3.17-43oyx4B630gDZMbTh3Ttji
    smallcheck-1.1.5-IcJgcWLNXQN4xE4F00EnpE
    store-core-0.4.4.1-88VHVSUIahwun1lQttQeS
    syb-0.7.1-1gO4OjQOULM8usUjWwwEyW template-haskell-2.14.0.0
    text-1.2.3.1 th-lift-0.8.0.1-27iw5a8l71Jv8yDjPHfmr
    th-lift-instances-0.1.14-KASYyJM441aGLVgajki6ev
    th-orphans-0.13.9-Kj7oG1a3gHoFLKxAz30Iyt
    th-reify-many-0.1.9-G89688xYWjfFURMqNvAi7B
    th-utilities-0.2.3.1-3qJ3GV8o7vFIOfKV3fH5x1 time-1.8.0.2
    transformers-0.5.6.2
    unordered-containers-0.2.10.0-AdFIXUUlSRM50nV4OuQt9A
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
    void-0.7.3-3RYOrpJEx0UYkI9Ikv0XI
haddock-interfaces: /usr/share/doc/haskell-store/html/store.haddock
haddock-html: /usr/share/doc/haskell-store/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
